@@ -81,7 +81,7 @@ def collapse_template(template, classname=None):
       classname = ' ' + classname.strip()
   the_id = re.sub(r'[^A-Za-z0-9]', '', template.instanceName)
   return """\
-<a class="collapsed" data-toggle="collapse" href="#{}" role="button" aria-expanded="false" aria-controls="collapseExample"><span class="pdcaretopen"><i class="fas fa-caret-down"></i></span><span class="pdcaretclosed"><i class="fas fa-caret-right"></i></span> {}</a>
+<a class="collapsed" data-bs-toggle="collapse" href="#{}" role="button" aria-expanded="false" aria-controls="collapseExample"><span class="pdcaretopen"><i class="fas fa-caret-down"></i></span><span class="pdcaretclosed"><i class="fas fa-caret-right"></i></span> {}</a>
 <div class="collapse" id="{}"><div class="card card-body{} pb-1">{}</div></div>\
 """.format(the_id, template.subject_as_html(trim=True), the_id, classname, template.content_as_html())
 
@@ -100,13 +100,24 @@ def tabbed_templates_html(tab_group_name:str, *pargs)->str:
     tabs += '<li class="nav-item" role="presentation">\n'
     if index == 0:
       tabs += f'<a class="nav-link active" id="{tab_group_name}-{tab_id}-tab" data-toggle="tab" href="#{tab_group_name}-{tab_id}" role="tab" aria-controls="{tab_id}" aria-selected="true">{templ.subject}</a>\n'
-      tab_content += f'<div class="tab-pane fade show active" id="{tab_group_name}-{tab_id}" role="tabpanel" aria-labelledby="{tab_group_name}-{tab_id}-tab">{templ.content}</div>\n'      
+      tab_content += f'<div class="tab-pane fade show active" id="{tab_group_name}-{tab_id}" role="tabpanel" aria-labelledby="{tab_group_name}-{tab_id}-tab">\n'
+      tab_content += templ.content_as_html()
+      tab_content += '\n</div>\n'      
     else:
       tabs += f'<a class="nav-link" id="{tab_group_name}-{tab_id}-tab" data-toggle="tab" href="#{tab_group_name}-{tab_id}" role="tab" aria-controls="{tab_id}" aria-selected="false">{templ.subject}</a>\n'
-      tab_content += f'<div class="tab-pane fade" id="{tab_group_name}-{tab_id}" role="tabpanel" aria-labelledby="{tab_group_name}-{tab_id}-tab">{templ.content}</div>\n'      
+      tab_content += f'<div class="tab-pane fade" id="{tab_group_name}-{tab_id}" role="tabpanel" aria-labelledby="{tab_group_name}-{tab_id}-tab">\n'
+      tab_content += templ.content_as_html()
+      tab_content += '\n</div>\n'
     tabs += '</li>'
   tabs += '</ul>'
   tab_content += '</div>'  
   
   return tabs + tab_content
 
+def sum_if_defined(*pargs):
+  """Lets you add up the value of variables that are not in a list"""
+  total = 0
+  for source in pargs:
+    if defined(source):
+      total += value(source)
+  return total
\ No newline at end of file
